@@ -2,10 +2,8 @@
 # coding: utf-8
 
 """
-Few extensions on `pymarc.Record` to make certain checks and manipulations
-a bit easier.
-
-Documentation and Examples: https://github.com/miku/marcx
+Few extensions on `pymarc.Record` to make certain checks
+and manipulations a bit easier.
 """
 
 from pymarc.exceptions import FieldNotFound
@@ -14,8 +12,9 @@ import collections
 import itertools
 import jsonpath_rw as jpath
 import re
+import warnings
 
-__version__ = '0.1.16'
+__version__ = '0.1.17'
 
 __all__ = [
     'FatRecord',
@@ -24,13 +23,33 @@ __all__ = [
     'fieldgetter',
 ]
 
+class DotDict(dict):
+    """ Dot access for dictionaries. """
+    def __init__(self, d=None, **kwargs):
+        if d is None:
+            d = {}
+        if kwargs:
+            d.update(**kwargs)
+        for k, v in d.iteritems():
+            setattr(self, k, v)
+        for k in self.__class__.__dict__.keys():
+            if not (k.startswith('__') and k.endswith('__')):
+                setattr(self, k, getattr(self, k))
+
+    def __setattr__(self, name, value):
+        if isinstance(value, (list, tuple)):
+            value = [self.__class__(x) if isinstance(x, dict) else x for x in value]
+        else:
+            value = self.__class__(value) if isinstance(value, dict) else value
+        super(DotDict, self).__setattr__(name, value)
+        self[name] = value
+
 def _equals(value):
     """
     Equality test.
     """
     return lambda v: value == v
 
-
 def _not(value):
     """
     Usage example: `_not(_equal(...))`.
@@ -40,28 +59,24 @@ def _not(value):
     else:
         return lambda v: not v
 
-
 def _match(value):
     """
     Maps to `re.match` (match at the beginning of `v`).
     """
     return lambda v: re.match(value, v)
 
-
 def _search(value):
     """
     Maps to `re.search` (match anywhere in `v`).
     """
     return lambda v: re.search(value, v)
 
-
 def _startswith(value):
     """
     Maps to `string.startswith`.
     """
     return lambda v: v.startswith(value)
 
-
 def _endswith(value):
     """
     Maps to `string.endswith`.
@@ -75,7 +90,6 @@ def pairwise(iterable):
     it = iter(iterable)
     return itertools.izip(it, it)
 
-
 def valuegetter(*fieldspecs, **kwargs):
     """
     Modelled after `operator.itemgetter`. Takes a variable
@@ -142,7 +156,6 @@ def valuegetter(*fieldspecs, **kwargs):
         ', '.join(fieldspecs))
     return values
 
-
 def fieldgetter(*fieldspecs):
     """
     Similar to `valuegetter`, except this returns (`pymarc.Field`, value)
@@ -170,7 +183,6 @@ def fieldgetter(*fieldspecs):
         ', '.join(fieldspecs))
     return fields
 
-
 class FatRecord(Record):
     """
     A record with some extras.
@@ -418,7 +430,6 @@ class FatRecord(Record):
         del d['leader']
         return [s for s in [v.strip() for v in flatten(d)] if s]
 
-
 def flatten(struct):
     """Cleates a flat list of all items in structured output (dicts, lists, items)
     Examples:
@@ -450,7 +461,6 @@ def flatten(struct):
 
     return [struct]
 
-
 class marcdoc(dict):
     """ A wrapper around an dictionary that represents a MARC record.
 
@@ -478,6 +488,7 @@ class marcdoc(dict):
                                           md.x776z))
     """
     def __init__(self, document, default_prefix='_source', default_index='*'):
+        warnings.warn("deprecated", DeprecationWarning)
         dict.__init__(self, document)
         self.document = document
         self.expression_cache = {}
